==> xoonips-2.00a.tar.gz: xoonips-2.00a/xoonips/language/japaneseutf/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.8.4.2 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp login block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","検索");
define("_MB_XOONIPS_ITEM_ALL_LABEL","全て");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","タイトル & キーワード");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","新規登録");
define("_MB_XOONIPS_ACCOUNT_LPASS","パスワード紛失");
define("_MB_XOONIPS_ACCOUNT_USERNAME","ユーザ ID");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","パスワード");
define("_MB_XOONIPS_ACCOUNT_LOGIN","ログイン");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "アカウント情報" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "アカウント編集" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "グループ一覧" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "アイテム一覧" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "プライベートツリー編集" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "詳細検索" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "新規アイテム登録" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "メタデータ検索" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "インポート" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "グループ編集" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "グループ公開アイテム承認" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "グループツリー編集" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "グループ編集" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "ユーザ承認" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "公開アイテム承認" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "公開ツリー編集" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "イベントログ" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "インポート" );

?>

==> xoonips-3.24a.tar.gz: xoonips-3.24a/xoonips/language/japaneseutf/blocks.php <==
<?php
/* constant strings
 * $Revision: 1.16 $
 */

// _MB_<MODULENAME>_<STRINGNAME>

// xnp search block
define("_MB_XOONIPS_ITEM_SEARCH_LABEL","検索");
define("_MB_XOONIPS_ITEM_ADVANCED_SEARCH_LABEL","詳細検索");
define("_MB_XOONIPS_ITEM_ALL_LABEL","全て");
define("_MB_XOONIPS_ITEM_TITLE_AND_KEYWORD_LABEL","タイトル & キーワード");
define("_MB_XOONIPS_ITEM_METADATA_LABEL","メタデータ");

// xnp login block
define("_MB_XOONIPS_ACCOUNT_RNOW","新規登録");
define("_MB_XOONIPS_ACCOUNT_LPASS","パスワード紛失");
define("_MB_XOONIPS_ACCOUNT_USERNAME","ユーザ ID");
define("_MB_XOONIPS_ACCOUNT_PASSWORD","パスワード");
define("_MB_XOONIPS_ACCOUNT_LOGIN","ログイン");

// user menu block
define("_MB_XOONIPS_ACCOUNT_VIEW_ACCOUNT", "アカウント情報" );
define("_MB_XOONIPS_ACCOUNT_EDIT_ACCOUNT", "アカウント編集" );
define("_MB_XOONIPS_ACCOUNT_SHOW_USERS", "ユーザ一覧" );
define("_MB_XOONIPS_ACCOUNT_GROUP_LIST", "グループ一覧" );
define("_MB_XOONIPS_ACCOUNT_LISTING_ITEM", "アイテム一覧" );
define("_MB_XOONIPS_ACCOUNT_EDIT_PRIVATE_INDEX", "プライベートツリー編集" );
define("_MB_XOONIPS_ACCOUNT_ADVANCED_SEARCH", "詳細検索" );
define("_MB_XOONIPS_ACCOUNT_REGISTER_ITEM", "新規アイテム登録" );
define("_MB_XOONIPS_ACCOUNT_METADATA_SEARCH_LABEL", "メタデータ検索" );
define("_MB_XOONIPS_ACCOUNT_IMPORT", "インポート" );

// group admin menu block
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUPS", "グループ編集" );
define("_MB_XOONIPS_ACCOUNT_CERTIFY_GROUP_ITEMS", "グループ公開アイテム承認" );
define("_MB_XOONIPS_ACCOUNT_EDIT_GROUP_INDEX", "グループツリー編集" );

// moderator menu block
define("_MB_XOONIPS_MODERATOR_EDIT_GROUPS", "グループ編集" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_USERS", "ユーザ承認" );
define("_MB_XOONIPS_MODERATOR_CERTIFY_PUBLIC_ITEMS", "公開アイテム承認" );
define("_MB_XOONIPS_MODERATOR_EDIT_PUBLIC_INDEX", "公開ツリー編集" );
define("_MB_XOONIPS_MODERATOR_EVENT_LOG", "イベントログ" );
define("_MB_XOONIPS_MODERATOR_IMPORT", "インポート" );

define('_MB_XOONIPS_RANKING_VIEWED_ITEM', '最も多く閲覧されたアイテム ' );
define('_MB_XOONIPS_RANKING_DOWNLOADED_ITEM', '最も多くダウンロードされたアイテム' );
define('_MB_XOONIPS_RANKING_CONTRIBUTING_USER', '最も多く公開アイテムを作成したユーザ' );
define('_MB_XOONIPS_RANKING_SEARCHED_KEYWORD', '最も多く検索されたキーワード ' );
define('_MB_XOONIPS_RANKING_CONTRIBUTED_GROUP', '最も活気のあるグループ(グループインデックスへアイテムを登録した回数)' );

define('_MB_XOONIPS_RANKING_NEW_ITEM', '新着アイテム' );
define('_MB_XOONIPS_RANKING_NEW_GROUP', '新着グループ' );
define("_MB_XOONIPS_RANKING_EMPTY", "ランキングが空です"); 
define("_MB_XOONIPS_RANKING_RANK_STR", "位"); 

define("_MB_XOONIPS_SU_START", "suを開始する"); 
define("_MB_XOONIPS_SU_END", "su (<b>%s</b>) を終了する"); 

?>
